Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(303)

Unified Diff: third_party/WebKit/Source/core/dom/NodeIntersectionObserverData.h

Issue 1548523002: Use Document, rather than document element, for implicit root. (Closed) Base URL: https://chromium.googlesource.com/chromium/src@intersection-observer
Patch Set: Nits, comments, rebaseline Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/NodeIntersectionObserverData.h
diff --git a/third_party/WebKit/Source/core/dom/ElementIntersectionObserverData.h b/third_party/WebKit/Source/core/dom/NodeIntersectionObserverData.h
similarity index 54%
rename from third_party/WebKit/Source/core/dom/ElementIntersectionObserverData.h
rename to third_party/WebKit/Source/core/dom/NodeIntersectionObserverData.h
index b416f365ac5717580f3e2b65715e098fef4a4f0d..80faa6105470dd58ed8478bc45d6f61945e3811b 100644
--- a/third_party/WebKit/Source/core/dom/ElementIntersectionObserverData.h
+++ b/third_party/WebKit/Source/core/dom/NodeIntersectionObserverData.h
@@ -2,48 +2,48 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ElementIntersectionObserverData_h
-#define ElementIntersectionObserverData_h
+#ifndef NodeIntersectionObserverData_h
+#define NodeIntersectionObserverData_h
#include "platform/heap/Handle.h"
namespace blink {
-class Element;
+class Node;
class IntersectionObservation;
class IntersectionObserver;
-class ElementIntersectionObserverData : public GarbageCollectedFinalized<ElementIntersectionObserverData> {
+class NodeIntersectionObserverData : public GarbageCollectedFinalized<NodeIntersectionObserverData> {
public:
DECLARE_TRACE();
- ElementIntersectionObserverData();
- ~ElementIntersectionObserverData();
+ NodeIntersectionObserverData();
+ ~NodeIntersectionObserverData();
bool hasIntersectionObserver() const;
bool hasIntersectionObservation() const;
IntersectionObservation* getObservationFor(IntersectionObserver&);
void addObservation(IntersectionObservation&);
void removeObservation(IntersectionObserver&);
- void activateValidIntersectionObservers(Element&);
- void deactivateAllIntersectionObservers(Element&);
+ void activateValidIntersectionObservers(Node&);
+ void deactivateAllIntersectionObservers(Node&);
#if !ENABLE(OILPAN)
void dispose();
#endif
- WeakPtrWillBeRawPtr<Element> createWeakPtr(Element*);
+ WeakPtrWillBeRawPtr<Node> createWeakPtr(Node*);
private:
// IntersectionObservers for which the Element owning this data is root.
HeapHashSet<WeakMember<IntersectionObserver>> m_intersectionObservers;
// IntersectionObservations for which the Element owning this data is target.
HeapHashMap<Member<IntersectionObserver>, Member<IntersectionObservation>> m_intersectionObservations;
#if !ENABLE(OILPAN)
- OwnPtr<WeakPtrFactory<Element>> m_weakPointerFactory;
+ OwnPtr<WeakPtrFactory<Node>> m_weakPointerFactory;
#endif
};
} // namespace blink
-#endif // ElementIntersectionObserverData_h
+#endif // NodeIntersectionObserverData_h

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,48 +2,48 @@
private:
- // IntersectionObservers for which the Element owning this data is root.
+ // IntersectionObservers for which the Node owning this data is root.
HeapHashSet<WeakMember<IntersectionObserver>> m_intersectionObservers;
@@ -2,48 +2,48 @@
HeapHashSet<WeakMember<IntersectionObserver>> m_intersectionObservers;
- // IntersectionObservations for which the Element owning this data is target.
+ // IntersectionObservations for which the Node owning this data is target.
HeapHashMap<Member<IntersectionObserver>, Member<IntersectionObservation>> m_intersectionObservations;
#if !ENABLE(OILPAN)